@@ -9,14 +9,14 @@ This file contains helpful functions and classes for testing operations.
 
 import json
 from functools import wraps
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Tuple, Union
 from numpy import number
 
 import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.types import ColumnHeader, ColumnID, MultiLevelColumnHeader
+from mitosheet.types import ColumnHeader, ColumnID, GraphID, MultiLevelColumnHeader
 from mitosheet.utils import dfs_to_array_for_json, get_new_id
 
 
@@ -729,6 +729,7 @@ class MitoWidgetTestWrapper:
 
     def generate_graph(
         self, 
+        graph_id: str,
         graph_type: str, 
         sheet_index: number,
         safety_filter_turned_on_by_user: bool,
@@ -746,6 +747,7 @@ class MitoWidgetTestWrapper:
                 'type': 'graph_edit',
                 'step_id': get_new_id() if step_id is None else step_id,
                 'params': {
+                    'graph_id': graph_id,
                     'graph_preprocessing': {
                     'safety_filter_turned_on_by_user': safety_filter_turned_on_by_user
                     },
@@ -764,6 +766,51 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    def delete_graph(self, graph_id: GraphID) -> bool:
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'graph_delete_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'graph_id': graph_id,
+                }
+            }
+        )
+
+    def duplicate_graph(self, old_graph_id: GraphID, new_graph_id: GraphID) -> bool:
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'graph_duplicate_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'old_graph_id': old_graph_id,
+                    'new_graph_id': new_graph_id
+                }
+            }
+        )
+
+
+    def rename_graph(self, graph_id: GraphID, new_graph_tab_name: str) -> bool:
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'graph_rename_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'graph_id': graph_id,
+                    'new_graph_tab_name': new_graph_tab_name
+                }
+            }
+        )
+
 
     def get_formula(self, sheet_index: int, column_header: ColumnHeader) -> str:
         """
@@ -823,9 +870,46 @@ class MitoWidgetTestWrapper:
         """
         Returns the graph_data object 
         """
-        return self.mito_widget.steps_manager.curr_step.final_defined_state.graph_data[graph_id]
+        if graph_id in self.mito_widget.steps_manager.curr_step.final_defined_state.graph_data_dict.keys():
+            return self.mito_widget.steps_manager.curr_step.final_defined_state.graph_data_dict[graph_id]
+        else:
+            return {}
 
+    def get_graph_type(self, graph_id: str) -> str:
+        """
+        Returns the graph type 
+        """
+        graph_data = self.get_graph_data(graph_id)
+        if bool(graph_data):
+            return graph_data["graphParams"]["graphCreation"]["graph_type"]
+        return ''
+
+    def get_graph_sheet_index(self, graph_id: str) -> int:
+        """
+        Returns the graph sheet index 
+        """
+        graph_data = self.get_graph_data(graph_id)
+        if bool(graph_data):
+            return graph_data["graphParams"]["graphCreation"]["sheet_index"]
+        return -1
+
+    def get_graph_axis_column_ids(self, graph_id: str, axis: str) -> List[str]:
+        """
+        Returns the graph axis column ids for either the x or y axis
+        """
+        graph_data = self.get_graph_data(graph_id)
+        if bool(graph_data):
+            if axis == 'x':
+                return graph_data["graphParams"]["graphCreation"]["x_axis_column_ids"]
+            if axis == 'y':
+                return graph_data["graphParams"]["graphCreation"]["y_axis_column_ids"]
+        return []
     
+    def get_is_graph_output_none(self, graph_id: str) -> bool:
+        """
+        Returns true if all of the graphOuput is does not exist.
+        """
+        return "graphOutput" not in self.get_graph_data(graph_id)
 
 def create_mito_wrapper(sheet_one_A_data: List[Any], sheet_two_A_data: List[Any]=None) -> MitoWidgetTestWrapper:
     """
